@@ -1,7 +1,4 @@
-from box import Box, BoxList
-import gam_gate as gam
 from gam_gate import log
-import gam_g4 as g4
 import time
 import random
 import sys
@@ -35,7 +32,7 @@ class Simulation:
 
         # G4 elements
         self.g4_RunManager = None
-        self.g4_PhysList = None  # FIXME will be changed
+        self.g4_PhysList = None
         self.g4_HepRandomEngine = None
         self.g4_ui = None
         self.g4_exception_handler = None
@@ -154,11 +151,11 @@ class Simulation:
 
         # create the RunManager
         if ui.number_of_threads > 1 or ui.force_multithread_mode:
-            log.info(f'Simulation: create G4MTRunManager with {ui.number_of_threads} threads')
+            log.info(f'Simulation: create MTRunManager with {ui.number_of_threads} threads')
             rm = g4.G4MTRunManager()
             rm.SetNumberOfThreads(ui.number_of_threads)
         else:
-            log.info('Simulation: create G4RunManager')
+            log.info('Simulation: create RunManager')
             rm = g4.G4RunManager()
         self.g4_RunManager = rm
         self.g4_RunManager.SetVerboseLevel(ui.g4_verbose_level)
@@ -194,6 +191,7 @@ class Simulation:
 
         # Actors initialization (before the RunManager Initialize)
         self.actor_manager.create_actors(self.action_manager)
+        self.source_manager.initialize_actors(self.actor_manager.actors)
 
         # Initialization
         log.info('Simulation: initialize G4RunManager')
@@ -259,7 +257,6 @@ class Simulation:
                  + f'-' * 80)
 
     def initialize_random_engine(self):
-        # FIXME add more random engine later
         engine_name = self.user_info.random_engine
         self.g4_HepRandomEngine = None
         if engine_name == 'MixMaxRng':
@@ -279,7 +276,7 @@ class Simulation:
             self.actual_random_seed = self.user_info.random_seed
 
         # set the seed
-        g4.G4Random.setTheSeeds(self.actual_random_seed, 0)
+        g4.G4Random.setTheSeed(self.actual_random_seed, 0)
 
     def initialize_g4_verbose(self):
         # For a unknow reason, when verbose_level == 0, there are some
