@@ -4,7 +4,8 @@ import gam_g4 as g4
 
 class PhaseSpaceActor(g4.GamPhaseSpaceActor, gam.ActorBase):
     """
-    FIXME TODO
+    Similar to HitsCollectionActor : store a list of hits.
+    However only the first hit of given event is stored here.
     """
 
     type_name = 'PhaseSpaceActor'
@@ -15,6 +16,7 @@ class PhaseSpaceActor(g4.GamPhaseSpaceActor, gam.ActorBase):
         # options
         user_info.attributes = []
         user_info.output = f'{user_info.name}.root'
+        user_info.phsp_gan_flag = False
 
     def __init__(self, user_info):
         gam.ActorBase.__init__(self, user_info)
