@@ -9,6 +9,9 @@ from inspect import getframeinfo, stack
 import pkg_resources
 import sys
 from pathlib import Path
+import random
+import string
+import os
 
 color_error = colored.fg("red") + colored.attr("bold")
 color_warning = colored.fg("orange_1")
@@ -160,3 +163,38 @@ def check_filename_type(filename):
     if isinstance(filename, Path):
         return (str(filename))
     return (filename)
+
+
+def get_random_folder_name(size=8):
+    r = ''.join(random.choices(string.ascii_lowercase + string.digits, k=size))
+    r = 'run.' + r
+    if not os.path.exists(r):
+        print(f'Creating output folder {r}')
+        os.mkdir(r)
+    if not os.path.isdir(r):
+        gam.fatal(f'Error, while creating {r}.')
+    return r
+
+
+def import_gaga_phsp():
+    # Try to import torch
+    try:
+        import torch
+    except:
+        gam.fatal(f'The module "torch" is needed, see https://pytorch.org/get-started/locally/ to install it')
+
+    # Try to import gaga_phsp
+    try:
+        import gaga_phsp as gaga
+    except:
+        gam.fatal('The module "gaga_phsp" is needed. Use \' pip install gaga_phsp\'')
+
+    # Check minimal version of gaga_phsp
+    import pkg_resources
+    from packaging import version
+    gaga_version = pkg_resources.get_distribution('gaga_phsp').version
+    gaga_minimal_version = '0.5.8'
+    if version.parse(gaga_version) < version.parse(gaga_minimal_version):
+        gam.fatal("The minimal version of gaga_phsp is not correct. You should install at least the version "
+                  + gaga_minimal_version + ". Your version is " + gaga_version)
+    return gaga
