@@ -127,7 +127,6 @@ def get_transform_orbiting(position, axis, angle_deg):
     rot = Rotation.from_euler(axis, angle_deg, degrees=True)
     t = rot.apply(p)
     return t, rot.as_matrix()
-    return t, rot
 
 
 def get_transform_world_to_local(vol_name):
@@ -166,7 +165,12 @@ def repeat_ring(name, start_deg, nb, translation, axis=[0, 0, 1]):
     return le
 
 
-def repeat_array(name, start, size, translation):
+def repeat_array(name, size, translation):
+    start = [-(x - 1) * y / 2.0 for x, y in zip(size, translation)]
+    return repeat_array_start(name, start, size, translation)
+
+
+def repeat_array_start(name, start, size, translation):
     le = [{'name': f'{name}_{x}_{y}_{z}',
            'rotation': Rotation.identity().as_matrix(),
            'translation': [start[0] + translation[0] * x,
@@ -176,3 +180,35 @@ def repeat_array(name, start, size, translation):
           for x, y, z in np.ndindex((size[0], size[1], size[2]))]
     return le
 
+
+def build_param_repeater(sim, mother_name, repeated_vol_name, size, translation):
+    vol = sim.get_volume_user_info(repeated_vol_name)
+    vol.build_physical_volume = False
+    param = sim.add_volume('RepeatParametrised', f'{repeated_vol_name}_param')
+    param.mother = mother_name
+    param.repeated_volume_name = repeated_vol_name
+    param.translation = None
+    param.rotation = None
+    param.linear_repeat = size
+    param.translation = translation
+    param.start = [-(x - 1) * y / 2.0 for x, y in zip(size, translation)]
+    param.offset_nb = 1
+    param.offset = [0, 0, 0]
+    return param
+
+
+def volume_orbiting_transform(axis, start, end, n, initial_t, initial_rot):
+    angle = start
+    step_angle = (end - start) / n
+    translations = []
+    rotations = []
+    for r in range(n):
+        irot = Rotation.from_matrix(initial_rot)
+        t, rot = gam.get_transform_orbiting(initial_t, axis, angle)
+        rot = Rotation.from_matrix(rot)
+        rot = rot * irot
+        translations.append(t)
+        r = gam.rot_np_as_g4(rot.as_matrix())
+        rotations.append(r)
+        angle += step_angle
+    return translations, rotations
