@@ -69,7 +69,7 @@ class SourceManager:
         for source in self.sources:
             if source.user_info.name == name:
                 return source.g4_source
-        gam.fatal(f'The source {name} is not in the current '
+        gam.fatal(f'The source "{name}" is not in the current '
                   f'list of sources: {self.user_info_sources}')
 
     def get_source_MT(self, name, thread):
@@ -83,7 +83,7 @@ class SourceManager:
                 if i == thread:
                     return source.g4_source
                 i += 1
-        gam.fatal(f'The source {name} is not in the current '
+        gam.fatal(f'The source "{name}" is not in the current '
                   f'list of sources: {self.user_info_sources}')
 
     def add_source(self, source_type, name):
@@ -102,6 +102,10 @@ class SourceManager:
         if len(self.user_info_sources) == 0:
             gam.warning(f'No source: no particle will be generated')
 
+    def initialize_actors(self, actors):
+        actors = [actors[a] for a in actors]
+        self.g4_master_source_manager.SetActors(actors)
+
     def build(self):
         # create particles table # FIXME in physics ??
         self.particle_table = g4.G4ParticleTable.GetParticleTable()
@@ -137,7 +141,7 @@ class SourceManager:
 
     def start(self):
         # FIXME (1) later : may replace BeamOn with DoEventLoop
-        # FIXME to allow better control on geometry between the different runs
-        # FIXME (2) : check estimated nb of particle, warning if too large
+        # to allow better control on geometry between the different runs
+        # (2) : check estimated nb of particle, warning if too large
         # start the master thread (only main thread)
         self.g4_master_source_manager.StartMasterThread()
