@@ -8,7 +8,7 @@ import os
 
 pathFile = pathlib.Path(__file__).parent.resolve()
 
-cmd = os.path.join(pathFile, 'test022_half_life.py') + ' 3'
+cmd = 'python ' + os.path.join(pathFile, 'test022_half_life.py') + ' 3'
 r = os.system(cmd)
 
 sys.exit(r)
