@@ -57,9 +57,10 @@ hole.translation = None
 hole.rotation = None
 
 size = [77, 100, 1]
-#size = [7, 10, 1] #FIXME
+#size = [7, 10, 1] 
 tr = [7.01481 * mm, 4.05 * mm, 0]
-## FIXME FIXME not correct position
+
+## not correct position
 start = [-(size[0] * tr[0]) / 2.0, -(size[1] * tr[1]) / 2.0, 0]
 r1 = gam.repeat_array('colli1', start, size, tr)
 start[0] += 3.50704 * mm
@@ -97,15 +98,16 @@ hc.mother = crystal.name
 hc.output = paths.output / 'test027.root'
 hc.attributes = ['KineticEnergy', 'PostPosition', 'PrePosition',
                  'TotalEnergyDeposit', 'GlobalTime',
-                 'VolumeName', 'TrackID',
-                 'VolumeCopyNo', 'VolumeInstanceID']
+                 'TrackVolumeName', 'TrackID', 'PreStepUniqueVolumeID',
+                 'PostStepUniqueVolumeID',
+                 'TrackVolumeCopyNo', 'TrackVolumeInstanceID']
 
 # singles collection
 sc = sim.add_actor('HitsAdderActor', 'Singles')
 sc.mother = crystal.name
 sc.input_hits_collection = 'Hits'
-sc.policy = 'TakeEnergyWinner'
-# sc.policy = 'TakeEnergyCentroid'
+sc.policy = 'EnergyWinnerPosition'
+# sc.policy = 'EnergyWeightedCentroidPosition'
 # same filename, there will be two branches in the file
 sc.output = hc.output
 
