@@ -29,7 +29,7 @@ def create_spect_simu(sim, paths, number_of_threads=1):
     world.material = 'G4_AIR'
 
     # spect head (debug mode = very small collimator)
-    spect = gam_spect.add_spect(sim, 'spect', collimator=False, debug=False)
+    spect = gam_spect.add_ge_nm67_spect_head(sim, 'spect', collimator=False, debug=False)
     psd = 6.11 * cm
     spect.translation = [0, 0, -(20 * cm + psd)]
 
@@ -103,15 +103,16 @@ def create_spect_simu(sim, paths, number_of_threads=1):
     hc.mother = crystal.name
     print('Crystal : ', crystal.name)
     hc.output = paths.output / 'test028.root'
-    hc.attributes = ['PostPosition', 'TotalEnergyDeposit',
+    hc.attributes = ['PostPosition', 'TotalEnergyDeposit', 'TrackVolumeCopyNo',
+                     'PreStepUniqueVolumeID', 'PostStepUniqueVolumeID',
                      'GlobalTime', 'KineticEnergy', 'ProcessDefinedStep']
 
     # singles collection
     sc = sim.add_actor('HitsAdderActor', 'Singles')
     sc.mother = crystal.name
     sc.input_hits_collection = 'Hits'
-    sc.policy = 'TakeEnergyWinner'
-    # sc.policy = 'TakeEnergyCentroid'
+    sc.policy = 'EnergyWinnerPosition'
+    # sc.policy = 'EnergyWeightedCentroidPosition'
     sc.skip_attributes = ['KineticEnergy', 'ProcessDefinedStep', 'KineticEnergy']
     sc.output = hc.output
 
@@ -148,7 +149,7 @@ def test_add_proj(sim, paths):
     # we set two times the spectrum channel to compare with Gate output
     proj.input_hits_collections = ['spectrum', 'scatter', 'peak140', 'spectrum']
     proj.spacing = [4.41806 * mm, 4.41806 * mm]
-    proj.dimension = [128, 128]
+    proj.size = [128, 128]
     # proj.plane = 'XY' # not implemented yet
     proj.output = paths.output / 'proj028.mhd'
     return proj
@@ -169,7 +170,7 @@ def test_spect_hits(sim, paths):
     gam.warning('Compare hits')
     gate_file = paths.gate_output / 'hits.root'
     hc_file = sim.get_actor_user_info("Hits").output
-    checked_keys = [{'k1': 'posX', 'k2': 'PostPosition_X', 'tol': 1.4, 'scaling': 1},
+    checked_keys = [{'k1': 'posX', 'k2': 'PostPosition_X', 'tol': 1.7, 'scaling': 1},
                     {'k1': 'posY', 'k2': 'PostPosition_Y', 'tol': 1.3, 'scaling': 1},
                     {'k1': 'posZ', 'k2': 'PostPosition_Z', 'tol': 0.9, 'scaling': 1},
                     {'k1': 'edep', 'k2': 'TotalEnergyDeposit', 'tol': 0.001, 'scaling': 1},
@@ -182,7 +183,7 @@ def test_spect_hits(sim, paths):
     gam.warning('Compare singles')
     gate_file = paths.gate_output / 'hits.root'
     hc_file = sim.get_actor_user_info("Singles").output
-    checked_keys = [{'k1': 'globalPosX', 'k2': 'PostPosition_X', 'tol': 1.4, 'scaling': 1},
+    checked_keys = [{'k1': 'globalPosX', 'k2': 'PostPosition_X', 'tol': 1.6, 'scaling': 1},
                     {'k1': 'globalPosY', 'k2': 'PostPosition_Y', 'tol': 1.3, 'scaling': 1},
                     {'k1': 'globalPosZ', 'k2': 'PostPosition_Z', 'tol': 0.05, 'scaling': 1},
                     {'k1': 'energy', 'k2': 'TotalEnergyDeposit', 'tol': 0.001, 'scaling': 1}]
@@ -191,7 +192,7 @@ def test_spect_hits(sim, paths):
 
     # Compare root files
     print()
-    gam.warning('Compare singles and spectrum')
+    gam.warning('Compare singles and spectrum (must be strictly equal)')
     ref_file = sim.get_actor_user_info("Singles").output
     hc_file = sim.get_actor_user_info("EnergyWindows").output
     checked_keys = [{'k1': 'PostPosition_X', 'k2': 'PostPosition_X', 'tol': 0.001, 'scaling': 1},
@@ -199,24 +200,24 @@ def test_spect_hits(sim, paths):
                     {'k1': 'PostPosition_Z', 'k2': 'PostPosition_Z', 'tol': 0.001, 'scaling': 1},
                     {'k1': 'TotalEnergyDeposit', 'k2': 'TotalEnergyDeposit', 'tol': 0.001, 'scaling': 1}]
     is_ok = gam.compare_root2(ref_file, hc_file, "Singles", "spectrum", checked_keys,
-                              paths.output / 'test028_spectrum.png') and is_ok
+                              paths.output / 'test028_spectrum.png', n_tol=0.01) and is_ok
 
     # Compare root files
     print()
     gam.warning('Compare scatter')
     hc_file = sim.get_actor_user_info("EnergyWindows").output
-    checked_keys = [{'k1': 'globalPosX', 'k2': 'PostPosition_X', 'tol': 15, 'scaling': 1},
-                    {'k1': 'globalPosY', 'k2': 'PostPosition_Y', 'tol': 10, 'scaling': 1},
+    checked_keys = [{'k1': 'globalPosX', 'k2': 'PostPosition_X', 'tol': 20, 'scaling': 1},
+                    {'k1': 'globalPosY', 'k2': 'PostPosition_Y', 'tol': 15, 'scaling': 1},
                     {'k1': 'globalPosZ', 'k2': 'PostPosition_Z', 'tol': 0.2, 'scaling': 1},
                     {'k1': 'energy', 'k2': 'TotalEnergyDeposit', 'tol': 0.2, 'scaling': 1}]
     is_ok = gam.compare_root2(gate_file, hc_file, "scatter", "scatter",
-                              checked_keys, paths.output / 'test028_scatter.png', n_tol=12) and is_ok
+                              checked_keys, paths.output / 'test028_scatter.png', n_tol=13) and is_ok
 
     # Compare root files
     print()
     gam.warning('Compare peak')
     hc_file = sim.get_actor_user_info("EnergyWindows").output
-    checked_keys = [{'k1': 'globalPosX', 'k2': 'PostPosition_X', 'tol': 1.3, 'scaling': 1},
+    checked_keys = [{'k1': 'globalPosX', 'k2': 'PostPosition_X', 'tol': 1.6, 'scaling': 1},
                     {'k1': 'globalPosY', 'k2': 'PostPosition_Y', 'tol': 1, 'scaling': 1},
                     {'k1': 'globalPosZ', 'k2': 'PostPosition_Z', 'tol': 0.1, 'scaling': 1},
                     {'k1': 'energy', 'k2': 'TotalEnergyDeposit', 'tol': 0.1, 'scaling': 1}]
@@ -246,8 +247,8 @@ def test_spect_proj(sim, paths, proj):
     img.SetSpacing(spacing)
     img.SetOrigin(origin)
     itk.imwrite(img, str(paths.output / 'proj028_offset.mhd'))
-    is_ok = gam.assert_images(paths.gate_output / 'projection.mhd',
-                              paths.output / 'proj028_offset.mhd',
+    is_ok = gam.assert_images(paths.output / 'proj028_offset.mhd',
+                              paths.gate_output / 'projection.mhd',
                               stats, tolerance=14, ignore_value=0, axis='y') and is_ok
 
     gam.test_ok(is_ok)
