@@ -5,7 +5,7 @@ import gam_gate as gam
 import contrib.gam_ge_nm670_spect as gam_spect
 from test028_ge_nm670_spect_base import *
 
-paths = gam.get_common_test_paths(__file__, 'gate_test028_ge_nm670_spect')
+paths = gam.get_default_test_paths(__file__, 'gate_test028_ge_nm670_spect')
 
 # create the simulation
 sim = gam.Simulation()
