@@ -33,7 +33,7 @@ world.size = [2 * m, 2 * m, 2 * m]
 world.material = 'G4_AIR'
 
 # spect head
-spect = gam_spect.add_spect(sim, 'spect', collimator=False, debug=False)
+spect = gam_spect.add_ge_nm67_spect_head(sim, 'spect', collimator=False, debug=False)
 initial_rot = Rotation.from_euler('X', 90, degrees=True)
 t, rot = gam.get_transform_orbiting([0, 25 * cm, 0], 'Z', 0)
 rot = Rotation.from_matrix(rot)
@@ -83,13 +83,14 @@ stat.output = paths.output / 'stats029.txt'
 hc = sim.add_actor('HitsCollectionActor', 'Hits')
 hc.mother = 'spect_crystal'
 hc.output = ''  # No output
-hc.attributes = ['PostPosition', 'TotalEnergyDeposit']
+hc.attributes = ['PostPosition', 'TotalEnergyDeposit',
+                 'PostStepUniqueVolumeID', 'GlobalTime']
 
 # singles collection
 sc = sim.add_actor('HitsAdderActor', 'Singles')
 sc.mother = hc.mother
 sc.input_hits_collection = 'Hits'
-sc.policy = 'TakeEnergyCentroid'
+sc.policy = 'EnergyWeightedCentroidPosition'
 sc.output = hc.output
 
 # EnergyWindows
@@ -102,12 +103,11 @@ cc.channels = [{'name': 'scatter', 'min': 114 * keV, 'max': 126 * keV},
 cc.output = hc.output
 
 # projection
-# (FIXME: visu does not work on Linux when python callback during run)
 proj = sim.add_actor('HitsProjectionActor', 'Projection')
 proj.mother = hc.mother
 proj.input_hits_collections = ['Singles', 'scatter', 'peak140']
 proj.spacing = [4.41806 * mm, 4.41806 * mm]
-proj.dimension = [128, 128]
+proj.size = [128, 128]
 proj.output = paths.output / 'proj029.mhd'
 
 # motion of the spect, create also the run time interval
