@@ -63,7 +63,7 @@ source.activity = 20000 * Bq
 dose = sim.add_actor('DoseActor', 'dose')
 dose.save = paths.output / 'test030-edep.mhd'
 dose.mother = 'waterbox'
-dose.dimension = [99, 99, 99]
+dose.size = [99, 99, 99]
 mm = gam.g4_units('mm')
 dose.spacing = [2 * mm, 2 * mm, 2 * mm]
 dose.translation = [2 * mm, 3 * mm, -2 * mm]
